ApiRequest class

Constructors

ApiRequest({required String route, bool auth = true, RequestType type = RequestType.post})

Properties

auth bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
route String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type RequestType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited